@@ -4,6 +4,7 @@ from typing import Optional, Sequence, List, Any
 from derobertis_cv.models.category import CategoryModel
 from derobertis_cv.models.grades.main import GradingModel
 from derobertis_cv.models.prereq import CoursePrerequsitesModel
+from derobertis_cv.models.resources import ResourceModel, ResourceSection
 from derobertis_cv.models.textbook import TextbookModel
 from derobertis_cv.models.university import UniversityModel
 from derobertis_cv.pltemplates.software.project import SoftwareProject
@@ -33,6 +34,7 @@ class CourseModel:
     current_period: Optional[str] = None
     current_time: Optional[str] = None
     software_projects: Optional[Sequence[SoftwareProject]] = None
+    resources: Optional[Sequence[ResourceSection]] = None
 
     @property
     def periods_taught_str(self) -> str:
